@@ -1,15 +1,15 @@
 package Perinci::Sub::Complete;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.81'; # VERSION
+our $DATE = '2015-09-09'; # DATE
+our $VERSION = '0.82'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any::IfLOG '$log';
 
-use Complete;
 use Complete::Util qw(hashify_answer complete_array_elem combine_answers);
+use Complete::Setting;
 use Perinci::Sub::Util qw(gen_modified_sub);
 
 require Exporter;
@@ -94,7 +94,7 @@ sub complete_from_schema {
     my %args = @_;
     my $sch  = $args{schema}; # must be normalized
     my $word = $args{word} // "";
-    my $ci   = $args{ci} // $Complete::OPT_CI;
+    my $ci   = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $fres;
     $log->tracef("[comp][periscomp] entering complete_from_schema, word=<%s>, schema=%s", $word, $sch);
@@ -333,7 +333,7 @@ sub complete_arg_val {
         $log->tracef("[comp][periscomp] arg is not supplied, declining");
         goto RETURN_RES;
     };
-    my $ci   = $args{ci} // $Complete::OPT_CI;
+    my $ci   = $args{ci} // $Complete::Setting::OPT_CI;
     my $word = $args{word} // '';
 
     # XXX reject if meta's v is not 1.1
@@ -486,7 +486,7 @@ sub complete_arg_elem {
         $log->tracef("[comp][periscomp] index is not supplied, declining");
         goto RETURN_RES;
     };
-    my $ci   = $args{ci} // $Complete::OPT_CI;
+    my $ci   = $args{ci} // $Complete::Setting::OPT_CI;
     my $word = $args{word} // '';
 
     # XXX reject if meta's v is not 1.1
@@ -779,7 +779,7 @@ sub complete_cli_arg {
         my $type  = $cargs{type};
         my $ospec = $cargs{ospec} // '';
         my $word  = $cargs{word};
-        my $ci    = $cargs{ci} // $Complete::OPT_CI;
+        my $ci    = $cargs{ci} // $Complete::Setting::OPT_CI;
 
         my $fres;
 
@@ -963,7 +963,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.81 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-09-03.
+This document describes version 0.82 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-09-09.
 
 =head1 SYNOPSIS
 
